==> haskell-resourcet-1.2.4.2-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resourcet
version:              1.2.4.2
visibility:           public
id:                   resourcet-1.2.4.2-1DyaIM7j2S98tFIrEn9sUe
key:                  resourcet-1.2.4.2-1DyaIM7j2S98tFIrEn9sUe
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  bd0816b13b52cabdf2d5142d3c6d28ff
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-8.10.3/site-local/resourcet-1.2.4.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/resourcet-1.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/resourcet-1.2.4.2
hs-libraries:         HSresourcet-1.2.4.2-1DyaIM7j2S98tFIrEn9sUe
depends:
    base-4.14.1.0 containers-0.6.2.1 exceptions-0.10.4 mtl-2.2.2
    primitive-0.7.1.0-BHpZg3vE1Nw1UsvUowjTgm transformers-0.5.6.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.2.4.2-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 resourcet
version:              1.2.4.2
visibility:           public
id:                   resourcet-1.2.4.2-CC4MPzVaA0R1Z8iZYJkFQ5
key:                  resourcet-1.2.4.2-CC4MPzVaA0R1Z8iZYJkFQ5
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  8eae6dc45ac69fd4a150445454ce2b39
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-8.10.3/site-local/resourcet-1.2.4.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/resourcet-1.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/resourcet-1.2.4.2
hs-libraries:         HSresourcet-1.2.4.2-CC4MPzVaA0R1Z8iZYJkFQ5
depends:
    base-4.14.1.0 containers-0.6.2.1 exceptions-0.10.4 mtl-2.2.2
    primitive-0.7.1.0-7rKtjeS7KhWBM14CtOkLrj transformers-0.5.6.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
